acRun <- function (p, xFrame, timevec = seq(0, 15, 1), sim.interstudy = TRUE, 
    pboEffect = TRUE, xi = 1) 
{
    parallel <- length(unique(xFrame$DoseEnd)) == 1
    t0 <- timevec
    kel <- p["kel"]
    keq <- kel + p["keqMinusKel"]
    beta <- -p["aucPlacebo"]/(1/kel - 1/keq)
    ePlacebo <- beta * (exp(-kel * t0) - exp(-keq * t0))
    t1 <- t(sapply(xFrame$DoseBegin, function(dbt) t0 - dbt))
    t2 <- t(sapply(xFrame$DoseEnd, function(det) t0 - det))
    t1[t1 < 0 | t2 > 0] <- 0
    t2[t2 < 0] <- 0
    emaxSx <- xFrame$emaxSx
    et50Sx <- xFrame$et50Sx
    esx <- emaxSx * t1/(et50Sx + t1)
    et50SxWash <- xFrame$et50SxWash
    ifelse(parallel, esxDoseEnd <- esx[, ncol(esx)], esxDoseEnd <- as.numeric(sapply(1:nrow(esx), 
        function(i) esx[i, t0 == xFrame[i, "DoseEnd"]])))
    esxWashout <- (esxDoseEnd * exp(-log(2) * t2/et50SxWash)) * 
        (t2 > 0)
    age <- xFrame$Age
    bmmse <- xFrame$Bmmse
    apoe <- xFrame$ApoE
    gender <- xFrame$Gender
    n <- nrow(xFrame)
    theta <- NA
    failedRuns <- 0
    while( any(is.na(theta)) ){
      if( failedRuns > 1000 ){ print("Failed to generate usable patient data.  Try sim.interstudy=FALSE"); break; }
      if (sim.interstudy) {
        muEta <- rnorm(1, p["nuEta"], p["psiEta"])
        muAlpha <- rnorm(1, p["nuAlpha"], p["psiAlpha"])
        tauEta <- rgamma(1, p["kappaEta"], p["kappaEta"] * p["phiEta"]^2)
        tauAlpha <- rgamma(1, p["kappaAlpha"], p["kappaAlpha"] * p["phiAlpha"]^2)
        tauEta <- rgamma(1, p["kappaEta"], p["kappaEta"] * p["phiEta"]^2)
        tauAlpha <- rgamma(1, p["kappaAlpha"], p["kappaAlpha"] * p["phiAlpha"]^2 )
        tauResid <- rgamma(1, p["kappaEpsilon"], p["kappaEpsilon"] * 
            p["phiEpsilon"]^2)
      }
      else {
        muEta <- p["nuEta"]
        muAlpha <- p["nuAlpha"]
        tauEta <- 1/p["phiEta"]^2
        tauAlpha <- 1/p["phiAlpha"]^2
        tauResid <- 1/p["phiEpsilon"]^2
      }

      muEtaAdj <- muEta + p["lambdaEtaBMMSE"] * (bmmse - 21)
      muAlphaAdj <- muAlpha + p["lambdaAlphaBMMSE"] * (bmmse - 
                                                       21) + p["lambdaAlphaAge"] * (age - 75) + p["lambdaAlphaApo1"] * 
                                                         (apoe == 1) + p["lambdaAlphaApo2"] * (apoe == 2) + p["lambdaAlphaGen"] * 
                                                           gender

      eta <- rnorm(n, muEtaAdj, 1/sqrt(tauEta))
      alpha <- rnorm(n, muAlphaAdj, 1/sqrt(tauAlpha))
      
      alphaTimesTime <- alpha %o% t0
      edm <- xFrame$eDm * muAlphaAdj * t1
      attDmAdjusted <- alphaTimesTime - edm
      ifelse(parallel, edmDoseEnd <- edm[, ncol(edm)], edmDoseEnd <- as.numeric(sapply(1:nrow(edm), 
                                                                            function(i) edm[i, t0 == xFrame[i, "DoseEnd"]])))
      sysComp <- t(eta + alphaTimesTime + esx + esxWashout - edm - 
                   edmDoseEnd * (t2 > 0))
      if (pboEffect) 
        sysComp <- sysComp + ePlacebo
      theta <- (1 + exp(-xi * sysComp))^(-1/xi)
      failedRuns <- failedRuns + 1
    }
    n.obs <- n * length(t0)

    adas <- 70 * rbeta(n.obs,
                       (theta + 1e-05) * tauResid,
                       (1 - theta + 1e-05) * tauResid)
    out <- xFrame[rep(1:nrow(xFrame), each = length(t0)), ]
    out$Time <- rep(timevec, nrow(xFrame))
    out$AdasCog <- adas
    out
}
