pAnalyzeParallel <-
function(dat, ep.time, method='MMRM') {
  require(nlme)
  require(contrast)
  baseline <- subset(dat, Time == 0)
  ind <- match(dat$Patient, baseline$Patient)
  dat$Baseline <- baseline$AdasCog[ind]
  dat$CBL <- with(dat, AdasCog - Baseline)
  dat$Arm <- factor(dat$Arm)
  dat <- subset(dat, Time > 0)
  dat$Time2 <- factor(dat$Time)

  if( method=='LME' ){
    conList <- lapply(1:length(ep.time),
                      function(i) {
                        ti <- ep.time[i]
                        dati <- subset(dat, Time <= ti)
                        modi <- lme(CBL ~ Arm * Time2 + Baseline,
                                    data = dati,
                                  random = ~ 1 | Patient)
                        coni <- contrast(modi,
                                         a = list(Arm = "B", Baseline = mean(dati$Baseline), Time2 = paste(ti)),
                                         b = list(Arm = "A", Baseline = mean(dati$Baseline), Time2 = paste(ti)),
                                         type = "individual"
                                         )
                        coni
                      }
                      )
  }
  if( method=='MMRM' ){
    dat$Visit <- as.numeric(dat$Time2)
    conList <- lapply(1:length(ep.time),        
                      function(i) {
                        ti <- ep.time[i]
                        dati <- subset(dat, Time <= ti)
                        modi <- gls(CBL ~ Arm * Time2 + Baseline,
                                    data = dati,
                                    correlation = corSymm(form = ~ Visit | Patient)
                                    )
                        coni <- contrast(modi,
                                         a = list(Arm = "B", Baseline = mean(dati$Baseline), Time2 = paste(ti)),
                                         b = list(Arm = "A", Baseline = mean(dati$Baseline), Time2 = paste(ti)),
                                         type = "individual"
                                         )
                        coni
                      }
                      )
  }
  conList <- lapply(conList, function(coni) unlist(coni[c(3:7, 9)]))
  res <- do.call('rbind', conList)
  if(is.matrix(res)) rownames(res) <- paste(ep.time)
  res
}

