pAnalyzeXover <-
function (dat, ep.time = max(dat$TimeWithin)) 

{

  ## This is an adjusted version of pAnalyzeXover that implements
  ## the primary analysis for the Varenicline phase 2 study.
  require(nlme)
  require(contrast)

  use.dat <- dat

  use.dat$Treatment <- "Placebo"
  ## use.dat$Treatment[(use.dat$Arm == "A" & use.dat$Period == 1) | 
  ##                   (use.dat$Arm == "B" & use.dat$Period == 2)] <- "Drug"
  use.dat$Treatment[with(use.dat, Time >= DoseBegin & Time <= DoseEnd)] <- "Drug"

  use.dat$Period <- factor(use.dat$Period)
  use.dat$Treatment <- factor(use.dat$Treatment, levels = c("Placebo", "Drug"))
  use.dat$Arm <- factor(use.dat$Arm)
  use.dat$Patient <- factor(use.dat$Patient)
  use.dat$TimeWithin <- factor(use.dat$TimeWithin)
  
  mod <- lme(fixed = AdasCog ~ Stratum + Site + Period + Arm + Treatment * TimeWithin,
             data = use.dat, 
             random = ~1 | Patient)
   
  con <- contrast(mod,
                  list(Treatment = "Drug", TimeWithin = paste(ep.time),
                       Period = levels(use.dat$Period), 
                       Arm = levels(use.dat$Arm),
                       Site = levels(use.dat$Site), 
                       Stratum = levels(use.dat$Stratum)
                       ),
                  list(Treatment = "Placebo", TimeWithin = paste(ep.time), 
                       Period = levels(use.dat$Period),
                       Arm = levels(use.dat$Arm),
                       Site = levels(use.dat$Site), 
                       Stratum = levels(use.dat$Stratum)
                       ), 
                  type = "average")
  
  res <- unlist(con[1:7])

  res

}

