\name{acRun}
\alias{acRun}
\title{Generate patient ADAS-cog values}
\description{
Given a randomization table of patients with demographic and treatment information for each,
ADAS-cog values are generated
}
\usage{
acRun(p, xFrame, timevec = seq(0, 15, 1), sim.interstudy = TRUE, pboEffect = TRUE, xi = 1)
}
\arguments{
  \item{p}{a vector including the named elements in
    \code{\link{posterior}} which specify the model}
  \item{xFrame}{ a data.frame with simulated patients, demographics,
    dosing regimens and treatment specifications.  The \code{\link{acRandomize}}
    function will provide such a data.frame.  Additionally, xFrame may
    contain a vector of dropout times for each patient in the variable
    \code{dropT}.  The function \code{dropTime} will simulate dropout
    times according to a Weibull-LogNormal frailty model
}
  \item{timevec}{
    time points at which ADAS-cog scores are to be simulated
}
  \item{sim.interstudy}{
    sample from inter-study random effects (\code{TRUE}) or just set all of those
    inter-study effects to expected values (\code{FALSE})
}
  \item{pboEffect}{
    when \code{TRUE}, the simulation assumption is that patient dosing intervals of
    \code{timevec} left unspecified in \code{xframe} are placebo treated
    intervals.  When \code{FALSE}, intervals follow natural progression
}
  \item{xi}{
    for use with the generalized logit,
    \deqn{ \xi^{-1} ln (\frac{\theta^\xi}{1-\theta^xi} ) }
}
}
\details{
  \code{acRun} will generate simulated
  ADAS-cog profiles for each patient in \code{xFrame} based upon
  their treatment schedule (determined by \code{DrugDose},
  \code{DoseBegin}, \code{DoseEnd}) and the drug effect (\code{emaxSx},
  \code{et50Sx}, \code{et50SxWash}, \code{eDm}).  
}
\value{
  A data.frame of simulated observable patient data.  The \code{xFrame}
  is expanded and matched to the ADAS-cog scores simulated for each
  patient at each time in \code{timevec} where \eqn{ timevec < dropT }.
}
\author{
Dan Polhamus
}

\seealso{
  \code{\link{acRandomize}}
  \code{\link{gLogitDelta}}
}
\examples{
  ## Following the examples in \code{\link{acRandomize}}:
  patientTable <- acRecruit(n.enrolled, p.use, lbMmse = lbMmse.use, ubMmse = ubMmse.use)
  baseTable <- acRandomize(patientTable, TrtSeqTable, TrtParTable)
  baseTable$dropT <- dropTime(baseTable, p.use)
  simdat <- acRun(p.use, baseTable, timevec = t.global, sim.interstudy = TRUE)

  head(simdat)
}
