\name{gLogitDelta}
\alias{gLogitDelta}
\title{
  Set Emax on logit scale for a hypothetical treatment
}
\description{
  Approximates the symptomatic \code{Emax} value on the logit scale
  that, given an \code{ET50}, corresponds to a given \eqn{E_{\Delta}^*}
  (at a reference point) on the ADAS-cog scale
}
\usage{
gLogitDelta(deltaAtRefTime = -2.5, refTime = 6 * 4, otherTimes = c(6, 12), refAdas = 25, xi = 1, et50 = 1)
}
\arguments{
  \item{deltaAtRefTime}{
    The drug effect at a reference time (\code{refTime}) on the ADAS-cog scale
  }
    \item{et50}{
    The \code{ET50} for the symptomatic treatment effect
  }
  \item{refTime}{
    time at which the estimated \code{Emax} will give desired
    \code{deltaAtRefTime} on ADAS-cog scale
    }
  \item{otherTimes}{
    Other times at which the logit should be calculated
  }
  \item{xi}{
    Parameter for the generalized logit.  The defatult (\eqn{\xi = 1})
    corresponds to the standard logit
  }
}
\details{
  The approximation is crude, and may require further tuning to match
  the required fixed difference at \code{refTime}.  The drug effect
  is assumed to follow a simple Emax-ET50 curve.  Using
  the reference score \eqn{ADAS_0}, the difference on the logit scale is
  approximated as the solution for \code{Emax} from :
  \eqn{logit( ADAS_0 + \code{deltaAtRefTime} ) - logit( ADAS_0 ) =
    \frac{\code{Emax}*t}{\code{et50} + t} }.
}
\value{
  \item{logitEmax }{\code{Emax} on the logit scale}
  \item{diffAtRefTime }{Delta on the logit scale at the reference time}
  \item{diffAtOtherTimes }{Delta at the other requested times (6 and 12
    weeks by default), again on the logit scale}
}
\author{
Dan Polhamus
}
