\name{pAnalyzeDelayedStart}
\alias{pAnalyzeDelayedStart}
\title{
Analysis for a delayed-start design
}
\description{
Function for analysis of a delayed-start (randomized-start) design.
Used for evaluating disease-modifying effects, the delayed-start design typically
consists of a placebo controlled phase, followed by a phase where all subjects are on the active treatment.  
}
\usage{
pAnalyzeDelayedStart(dat, ep.time, stab.time)
}
\arguments{
  \item{dat}{
    a data.frame generated by \code{\link{acRun}}, or one that exactly
    mimics that structure }
  \item{ep.time}{
    the end-of-period time points (a vector of length 2).  The first time point should be that at
    which the control arm is switched to the treatment and the second
    time point is the end of the trial
}
  \item{stab.time}{
    the time points on which which the stability hypothesis is to be
    tested, again a vector of length 2 
  }
}
\details{
  There are (at least) three hypotheses of interest in the delayed-start design:
\enumerate{
  \item The treatment effect and placebo effect differ at
  the end of phase I
  \item The treatment effect and placebo effect differ at the end of phase II 
  \item The effects in the constant-treatment group and
  placebo-active-treatment group are not converging on each other
}  
  The first group of hypotheses (a test on effect differences for each of \code{ep.time}) is
  performed using MMRM, repeated on visits. The second group of
  hypotheses is a test of slope equality that verifies that the
  disease-modifying effects persist and do not diminish over time.  
}
\value{
  A vector with the elements (for each \code{ep.time}):
\itemize{
  \item \code{Contrast}{ Point estimate for the treatment - placebo
    contrast }
  \item \code{SE}{ Standard error of the point estimate }
  \item \code{Lower, Upper}{ 95\% confidence bounds }
  \item \code{testStat}{ T statistic }
  \item \code{Pvalue}{ P-value of the test }
  \item \code{ArmX:Time}{ Point estimate for the difference in slope between
    ArmX and the reference Arm }
  \item \code{5\%, 95\%}{ 90\% bounds for the difference in slope
    between arms }
} 
} 
\references{
D'Agostino, Ralph B. The delayed-start study design. N Engl J Med,
2009;361(13), p1304-6.
}
\author{
  Dan Polhamus
}
\examples{
## Following the example from \code{\link{acRun}}
  simdat <- acRun(p.use, baseTable, timevec = t.global)

  ## Only keep the data that actually observable :
  simdat <- simdat[ simdat$Time < simdat$dropT, ]
  simdat <- simdat[ !is.na(simdat$AdasCog), ]

  pAnalyzeDelayedStart(simdat, ep.time = c(52, 91), stab.time = c(65, 91) 
}
