\name{pAnalyzeParallel}
\alias{pAnalyzeParallel}
\title{
Primary analysis for a parallel group design
}
\description{
  Fits a model based on changes from baseline. The model includes fixed
  terms for treatment, time (as categorical), and treatment by time
  interaction.  Both MMRM (repeated measures on visit) or LME (random
  effect on patient) analyses can be performed.
}
\usage{
pAnalyzeParallel(dat, ep.time, method='MMRM')
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{dat}{
    a data.frame generated by \code{\link{acRun}}, or one that exactly
    mimics that structure
  }
  \item{ep.time}{
    the assessment time of the primary endpoint
  }
  \item{method}{
    method of analysis, either MMRM or LME
  }
}
\details{ Both approaches (MMRM and LME) seek to answer the same
  question, but MMRM makes less assumptions on the correlation structure
  and is more sensible with only a few visits (e.g., <= 3) }
\value{
A vector with elements: 
  \item{Contrast}{Point estimate for the treatment - placebo contrast}
  \item{SE}{Standard error of the point estimate}
  \item{Lower, Upper}{95\% confidence bounds}
  \item{testStat}{T statistic}
  \item{Pvalue}{P-value for testing zero difference between drug and placebo}
}
\author{
Dan Polhamus
}
\examples{
## Continuing the examples from \code{\link{acRun}}
  simdat <- acRun(p.use, baseTable, timevec = t.global, sim.interstudy = TRUE)
  pAnalyzeParallel(simdat, ep.time = 24, method='MMRM')	
}
\keyword{ htest }% __ONLY ONE__ keyword per line
