\name{pAnalyzeXover}
\alias{pAnalyzeXover}
\title{
Primary analysis for a cross-over design
}
\description{
  Fits a linear mixed effects model based only on the ends-of-periods data and returns a p-value, a point estimate, and a confidence interval for the treatment - placebo contrast. 
}
\usage{
pAnalyzeXover(dat, ep.time = 6)
}

\arguments{
  \item{dat}{ a data.frame generated by \code{\link{acRun}}, or one that mimics that structure with the addition of the following variables: \code{Period}, \code{TimeWithin}, and \code{Strata}}
  \item{ep.time}{ the end-of-period time point. E.g., for a design with two 6 week treatment periods and a 3 week washout, \code{ep.time} should be \code{6}, since the assessment at the end of the first period is the week 6 assessment, and the assessment at the end of the second period is the 15 week assessment which occurs at the 6 week point of the second period.  }
}
\details{
  Because this analysis uses only the ends-of-periods data, it is a bit
  conservative / inefficient. On the other hand, if drug effects are possibly still washing out during the second period, the best course is to ignore the longitudinal data anyway. Besides, unless there are missing data, this analysis will provide essentially the same inferences as one that uses all of the longitudinal data. The additional variables required in \code{dat} will be worked into the function in the future, but for now they are elaborated upon as:
  \itemize{
  \item \code{Period} -- the treatment period of the design
  \item \code{TimeWithin} -- the time elapsed as of the beginning of the period
  \item \code{Strata} -- any stratification levels for the analysis (e.g., mild vs moderate CI based upon bMMSE)
  }
}
\value{
  A vector with elements: 
  \item{Contrast}{Point estimate for the treatment - placebo contrast}
  \item{SE}{Standard error of the point estimate}
  \item{Lower, Upper}{95\% confidence bounds}
  \item{testStat}{T statistic}
  \item{df}{Degrees of freedom}
  \item{Pvalue}{P-value for testing zero difference between drug and placebo}
  \item{IntPval}{P-value for testing hypothesis of no treatment-period interaction}
}
\author{
  Dan Polhamus
}
\examples{
simdat <- acRun(p.use, baseTable, timevec = t.global, sim.interstudy = TRUE)

## Now add the derived variables Period, Stratum, and TimeWithin
simdat$Period <- 1 + with(simdat, Time >= 9) ## Second group starts at week 6+3=9
simdat$Stratum <- factor(ifelse(simdat$Bmmse < 20, 'mild', 'moderate'))
simdat$TimeWithin <- with(simdat, Time %% 9)
pAnalyzeXover(simdat, 6)	
}
\keyword{ htest }

